@@ -42,7 +42,7 @@ def color_rep(ss, is_top_menu: bool = False):
         show_edge=False,
         box=SIMPLE,
     )
-    for i, line in enumerate(ss if is_top_menu else ss[1:]):
+    for line in ss if is_top_menu else ss[1:]:
         if ":->" in line:
             line = [i.strip() for i in line.split(":->")]
             if "|" in line[1]:
@@ -65,7 +65,8 @@ def base_menu():
     qs copy  <file>          :-> copy file to clipboard
     qs play  <file...>       :-> Play Musics
     qs lp    <file...>       :-> Print Files
-    qs sas                   :-> Switch Audio Source ()"""
+    qs sas                   :-> Switch Audio Source ()
+    qs swap <file1> <file2>  :-> Swap two files"""
     ) if user_lang != "zh" else color_rep(
         """基础工具:
     qs u   <链接...>          :-> 使用默认浏览器打开多个链接
@@ -78,7 +79,8 @@ def base_menu():
     qs copy  <文件>           :-> 拷贝文件到粘贴板
     qs play  <文件...>        :-> 播放音乐
     qs lp    <文件...>        :-> 打印文件
-    qs sas                   :-> 切换音频源 ()"""
+    qs sas                   :-> 切换音频源 ()
+    qs swap <文件1> <文件2>   :-> 交换两个文件"""
     )
 
 
@@ -176,7 +178,8 @@ def api_menu():
     qs m2t <-f path | -u link | *> :-> transform magnet link to torrent file
     qs d2m <designation> :-> search magnet url by designation
     qs doutu <keywords> :-> get expression package of keywords
-    qs joke :-> get a Chinese joke"""
+    qs joke :-> get a Chinese joke
+    qs gpt  :-> Official ChatGPT API (Support Record history)"""
     ) if user_lang != "zh" else color_rep(
         """API工具:
     qs trans  \[内容]       :-> 翻译命令参数或剪切板中的内容
@@ -207,7 +210,8 @@ def api_menu():
     qs m2t <-f 路径 | -u 链接 | *> :-> 转换磁力链接为种子文件
     qs d2m <番号> :-> 搜索番号的磁力链
     qs doutu <关键词> :-> 获取关键词的表情包
-    qs joke :-> 获取一个中文笑话"""
+    qs joke :-> 获取一个中文笑话
+    qs gpt  :-> ChatGPT 官方API (支持上下文)"""
     )
 
 
@@ -263,6 +267,7 @@ basic_funcs = {
     "copy": "copy",
     "lp": "qs_print",
     "sas": "sas",
+    "swap": "swap",
 }
 
 system_funcs = {
